@@ -1,6 +1,6 @@
 /*
     fileio
-    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2007 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@
 #define __FILEIO_H__
 
 
-#include "common.h"
+#include "gcommon.h"
 #ifdef HAVE_FCNTL_H
 # include <fcntl.h>
 #endif /* HAVE_FCNTL_H */
@@ -73,10 +73,8 @@ extern "C" {
 # define FILEIO_SEEK_END            SEEK_END
 #endif /* not G_OS_WIN32 */
 #define FILEIO_SHARE_DENY           0
-#define FILEIO_ACCESS_ALL           (FILEIO_ACCESS_READ | FILEIO_ACCESS_WRITE)
-#define FILEIO_SHARE_ALL            (FILEIO_SHARE_READ | FILEIO_SHARE_WRITE)
-#define FILEIO_ICON_SIZE_SMALL      0
-#define FILEIO_ICON_SIZE_LARGE      1
+#define FILEIO_ACCESS_ALL           (FILEIO_ACCESS_READ|FILEIO_ACCESS_WRITE)
+#define FILEIO_SHARE_ALL            (FILEIO_SHARE_READ|FILEIO_SHARE_WRITE)
 
 
 typedef struct _FileIO FileIO;
@@ -205,6 +203,13 @@ goffset
 fileio_size (FileIO *fio);
 
 
+/*  ja:ファイルの終端を設定する
+    fio,ファイルポインタ
+    RET,TRUE:正常終了,FALSE:エラー                                          */
+gboolean
+fileio_eof (FileIO *fio);
+
+
 /******************************************************************************
 *                                                                             *
 * ja:高レベルファイル入出力関数群                                             *
@@ -279,6 +284,13 @@ gboolean
 fileio_mkdir (const gchar *dir);
 
 
+/*  ja:ファイル/ディレクトリを削除する
+    path,ファイル/ディレクトリ名
+     RET,TRUE:正常終了,FALSE,エラー                                         */
+gboolean
+fileio_remove (const gchar *path);
+
+
 /******************************************************************************
 *                                                                             *
 * ja:ファイル時刻関数群                                                       *
@@ -321,11 +333,11 @@ fileio_getsystime (FileIOTime    *ftime,
 ******************************************************************************/
 /*  ja:ファイルのアイコンを取得する
          file,ファイル名
-    icon_size,FILEIO_ICON_SIZE_SMALL/FILEIO_ICON_SIZE_LARGE
+    icon_size,アイコンサイズ
           RET,pixbuf,NULL:エラー                                            */
 GdkPixbuf *
 fileio_extract_icon (const gchar *file,
-                     const guint  icon_size);
+                     GtkIconSize  icon_size);
 
 
 #ifdef __cplusplus
