@@ -195,7 +195,7 @@ file_is_type (const gchar *file)
 
                 path = g_path_is_absolute (str) ? g_strdup (str)
                                         : g_build_filename (dir, str, NULL);
-                result = fileio_isfile (path);
+                result = g_file_test (path, G_FILE_TEST_EXISTS);
                 g_free (path);
                 g_free (str);
               }
@@ -635,7 +635,7 @@ file_open_list (const gchar *file,
                 path = g_build_filename (dir, str, NULL);
               }
             g_free (str);
-            if (fileio_isfile (path))
+            if (g_file_test (path, G_FILE_TEST_EXISTS))
               {
                 glist = g_list_append (glist, path);
               }
@@ -748,7 +748,7 @@ file_open_edit (const gchar *file)
   gtk_widget_grab_focus (mmaid->list);
 
   /* ja:新規作成ではなく、ファイルが存在する時には履歴に加える */
-  if (file && fileio_isfile (file))
+  if (file && g_file_test (file, G_FILE_TEST_EXISTS))
     orz_history_add_file (ORZ_HISTORY (history), file);
   g_free (filename);
 
@@ -782,11 +782,11 @@ file_save_id3tag (const gchar  *file,
   buf[1] = 'A';
   buf[2] = 'G';
   g_memset (buf + 3, ' ', 124);
-  title   = buf    +  3;
-  artist  = title  + 30;
-  album   = artist + 30;
-  year    = album  + 30;
-  comment = year   +  4;
+  title   = (gchar *)buf +  3;
+  artist  = title        + 30;
+  album   = artist       + 30;
+  year    = album        + 30;
+  comment = year         +  4;
   if (id3tag->title)
     {
       tmp = g_convert (id3tag->title, -1,
