@@ -30,9 +30,7 @@
 #include "misc/fileio.h"
 #include "misc/gnugpl.h"
 #include "misc/license.h"
-#if ! GLIB_CHECK_VERSION(2,6,0)
-# include "misc/profile.h"
-#endif /* not GLIB_CHECK_VERSION(2,6,0) */
+#include "misc/profile.h"
 #include "orz/orzaccel.h"
 #include "orz/orzcomm.h"
 #include "orz/orzhistory.h"
@@ -181,10 +179,27 @@ main (int   argc,
   GObject *accel, *winmenu;
   GtkAccelGroup *accel_group;
   GtkWidget *handle, *vbox;
-  /* en:Drag&Drop */
+  /* en:Drag and Drop */
   GtkTargetEntry drag_types[1] = {{"text/uri-list", 0, 0}};
   /* ja:提供可能なセレクション */
   GtkTargetEntry targets[1] = {{"Melody maid ID3 Tag", 0, TARGET_MMAID}};
+  /* ja:コマンドライン */
+  gint array[2], def[2];
+  ArgumentBool arg_n, arg_p, arg_x;
+  ArgumentValue arg_h;
+  ArgumentArray arg_s;
+  ArgumentExit arg_g, arg_v;
+  ArgumentHelp arg_q;
+  ArgumentList arg_opts[] = {
+{"history", 'h',  "NUM",          N_("History"),     ARGUMENT_TYPE_VALUE, &arg_h},
+{"new",     'n',  "ON/OFF",       N_("New File"),    ARGUMENT_TYPE_BOOL,  &arg_n},
+{"profile", 'p',  "ON/OFF",       N_("Profile"),     ARGUMENT_TYPE_BOOL,  &arg_p},
+{"size",    's',  "WIDTH,HEIGHT", N_("Window Size"), ARGUMENT_TYPE_ARRAY, &arg_s},
+{"second",  'x',  "ON/OFF",       N_("Open Window"), ARGUMENT_TYPE_BOOL,  &arg_x},
+{"license", 'g',  NULL,           N_("GNU GENERAL PUBLIC LICENSE"), ARGUMENT_TYPE_EXIT,  &arg_g},
+{"version", 'v',  NULL,           N_("About"),       ARGUMENT_TYPE_EXIT,  &arg_v},
+{"help",    '?',  NULL,           N_("Help"),        ARGUMENT_TYPE_HELP,  &arg_q},
+{NULL,      '\0', NULL,           NULL,              0,                   NULL}};
 
   /* 初期化 */
   setlocale (LC_ALL, "");
@@ -333,61 +348,51 @@ main (int   argc,
         }
     }
 
-  /* ja:コマンドラインの解析 */
-  {
-    gint array[2], def[2];
-    ArgumentBool arg_n, arg_p, arg_x;
-    ArgumentValue arg_h;
-    ArgumentArray arg_s;
-    ArgumentExit arg_v;
-    ArgumentHelp arg_q;
-    ArgumentList arg_opts[] = {
-{"history", 'h',  "NUM",          N_("History"),     ARGUMENT_TYPE_VALUE, &arg_h},
-{"new",     'n',  "ON/OFF",       N_("New File"),    ARGUMENT_TYPE_BOOL,  &arg_n},
-{"profile", 'p',  "ON/OFF",       N_("Profile"),     ARGUMENT_TYPE_BOOL,  &arg_p},
-{"size",    's',  "WIDTH,HEIGHT", N_("Window Size"), ARGUMENT_TYPE_ARRAY, &arg_s},
-{"second",  'x',  "ON/OFF",       N_("Open Window"), ARGUMENT_TYPE_BOOL,  &arg_x},
-{"version", 'v',  NULL,           N_("About"),       ARGUMENT_TYPE_EXIT,  &arg_v},
-{"help",    '?',  NULL,           N_("Help"),        ARGUMENT_TYPE_HELP,  &arg_q},
-{NULL,      '\0', NULL,           NULL,              0,                   NULL}};
-
-    /* ja:ファイルの履歴 */
-    arg_h.val = orz_history_get_num (ORZ_HISTORY (history));
-    arg_h.def = 4;
-    /* ja:新規ファイル */
-    arg_n.flag = newfile;
-    arg_n.def = FALSE;
-    /* ja:レジストリ */
-    arg_p.flag = TRUE;
-    arg_p.def = TRUE;
-    /* ja:ウインドウサイズ */
-    array[0] = def_width;
-    array[1] = def_height;
-    def[0] = gdk_screen_width () * 2 / 3;
-    def[1] = gdk_screen_height () * 2 / 3;
-    arg_s.leng = 2;
-    arg_s.array = array;
-    arg_s.def = def;
-    /* ja:新規ウインドウ */
-    arg_x.flag = second;
-    arg_x.def = FALSE;
-    /* ja:バージョン */
-    arg_v.str =
+  /* ja:コマンドライン */
+  /* ja:ファイルの履歴 */
+  arg_h.val = orz_history_get_num (ORZ_HISTORY (history));
+  arg_h.def = 4;
+  /* ja:新規ファイル */
+  arg_n.flag = newfile;
+  arg_n.def = FALSE;
+  /* ja:レジストリ */
+  arg_p.flag = TRUE;
+  arg_p.def = TRUE;
+  /* ja:ウインドウサイズ */
+  array[0] = def_width;
+  array[1] = def_height;
+  def[0] = gdk_screen_width () * 2 / 3;
+  def[1] = gdk_screen_height () * 2 / 3;
+  arg_s.leng = 2;
+  arg_s.array = array;
+  arg_s.def = def;
+  /* ja:新規ウインドウ */
+  arg_x.flag = second;
+  arg_x.def = FALSE;
+  /* ja:ライセンス */
+  arg_g.str = gnugpl;
+  /* ja:バージョン */
+  arg_v.str =
 MMAID_VERSION_NOTICE"\n"
 MMAID_COPYRIGHT_NOTICE"\n"
 "This is free software; see the source for copying conditions.  There is NO\n"
 "warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n";
-    /* ja:ヘルプ */
-    arg_q.str = MMAID_COPYRIGHT_NOTICE"\n\n";
-    arg_files = arg_analyse (argv, arg_opts);
-    orz_history_set_num (ORZ_HISTORY (history), arg_h.val);
-    newfile = arg_n.flag;
-    if (!arg_p.flag)
-      user_config = NULL;
-    def_width = array[0];
-    def_height = array[1];
-    second = arg_x.flag;
-  }
+  /* ja:ヘルプ */
+  arg_q.str = MMAID_COPYRIGHT_NOTICE"\n\n";
+  /* ja:コマンドラインの解析 */
+  arg_files = arg_analyse (argv, arg_opts);
+  /* ja:ファイルの履歴 */
+  orz_history_set_num (ORZ_HISTORY (history), arg_h.val);
+  /* ja:新規ファイル */
+  newfile = arg_n.flag;
+  /* ja:レジストリ */
+  if (!arg_p.flag)
+    user_config = NULL;
+  /* ja:ウインドウサイズ */
+  def_width = array[0];
+  def_height = array[1];
+  /* ja:新規ウインドウ */
+  second = arg_x.flag;
 
   /* ja:メインウインドウ */
   window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
@@ -410,9 +415,8 @@ MMAID_COPYRIGHT_NOTICE"\n"
   gtk_widget_realize (window);
   gtk_widget_add_events (window, GDK_KEY_PRESS_MASK);
   /* en:Drag and Drop */
-  gtk_drag_dest_set (window, GTK_DEST_DEFAULT_MOTION
-                        | GTK_DEST_DEFAULT_HIGHLIGHT | GTK_DEST_DEFAULT_DROP,
-                                            drag_types, 1, GDK_ACTION_COPY);
+  gtk_drag_dest_set (window, GTK_DEST_DEFAULT_ALL,
+                    drag_types, G_N_ELEMENTS (drag_types), GDK_ACTION_COPY);
   g_signal_connect (G_OBJECT (window), "drag-data-received",
                                 G_CALLBACK (signal_drag_data_received), NULL);
 #ifdef G_OS_WIN32
@@ -434,6 +438,10 @@ MMAID_COPYRIGHT_NOTICE"\n"
   mdi = orz_mdi_new ();
   gtk_notebook_set_scrollable (GTK_NOTEBOOK (mdi), TRUE);
   gtk_notebook_set_tab_pos (GTK_NOTEBOOK (mdi), n_pos);
+  gtk_drag_dest_set (mdi, GTK_DEST_DEFAULT_ALL,
+                    drag_types, G_N_ELEMENTS (drag_types), GDK_ACTION_COPY);
+  g_signal_connect (G_OBJECT (mdi), "drag-data-received",
+                                G_CALLBACK (signal_drag_data_received), NULL);
   g_signal_connect (G_OBJECT (mdi), "close-window",
                                 G_CALLBACK (signal_close_window), NULL);
   g_signal_connect (G_OBJECT (mdi), "switch-window",
