@@ -20,7 +20,7 @@
 #define __MMAID_H__
 
 
-#include "common.h"
+#include "gcommon.h"
 #include "misc/misc.h"
 #ifdef G_OS_WIN32
 # include <tchar.h>
